Package org.openrewrite.java.internal
@NullMarked
package org.openrewrite.java.internal
-
ClassDescriptionDefault implementation of
JavaTypeFactory: each method looks up by key in a singleJavaTypeCache.Type mapping from type attribution given fromjava.lang.reflecttypes.Factory for constructingJavaTypeinstances during parsing.AJavaTypeSignatureBuilderthat produces cache keys using JVMS 4 descriptors for methods and variables, ensuring direct compatibility with type tables built from class files (where ASM provides the descriptors).