Package org.openrewrite.java.internal.parser
@NullMarked
package org.openrewrite.java.internal.parser
-
ClassDescriptionAs of 6.1.0, we are using
TypeTableto includeJavaParserdependencies as resources in the classpath, because including the whole JAR caused bloat in the size of recipe JARs and would often get blocked by security scanners that weren't able to recognize that these JAR resources were only used to parse templats and never executed and so didn't represent a security threat.Structured representation of JVMS type signatures, parsed from ASM.An array type (e.g.,[Ljava/lang/String;).A primitive type (e.g.,I,Z).Result of parsing a JVMS ClassSignature.A class type, possibly parameterized (e.g.,java/util/List<TE;>).A formal type parameter declaration (e.g.,T extends Comparable<T>).A type variable reference (e.g.,TE;).A wildcard type argument.Type tables are written as a TSV file with the following columns: groupId artifactId version classAccess className classSignature classSuperclassSignature classSuperinterfaceSignatures[] access memberName descriptor signature parameterNames exceptions[] elementAnnotations parameterAnnotations[] typeAnnotations[] constantValueReads a type table from the classpath, and writes per-artifact JARs to disk for matching artifact names.Options for controlling how type tables are read.Enhanced builder with convenience methods.Receives type metadata extracted from class files byTypeTable.Writer.