Class Varargs

java.lang.Object
org.openrewrite.java.marker.Varargs
All Implemented Interfaces:
org.openrewrite.marker.Marker, org.openrewrite.rpc.RpcCodec<Varargs>

public class Varargs extends Object implements org.openrewrite.marker.Marker, org.openrewrite.rpc.RpcCodec<Varargs>
Marks a J.ArrayType that was written using varargs syntax (...) rather than array brackets ([]). The element type and dimension space are modeled like any other array type; this marker only records that the type should be printed with .... Currently produced by the Javadoc parser for references such as {@link String#format(String, Object...)}.
  • Constructor Details

    • Varargs

      public Varargs()
  • Method Details

    • rpcSend

      public void rpcSend(Varargs after, org.openrewrite.rpc.RpcSendQueue q)
      Specified by:
      rpcSend in interface org.openrewrite.rpc.RpcCodec<Varargs>
    • rpcReceive

      public Varargs rpcReceive(Varargs before, org.openrewrite.rpc.RpcReceiveQueue q)
      Specified by:
      rpcReceive in interface org.openrewrite.rpc.RpcCodec<Varargs>