Package org.openrewrite.java.marker
@NullMarked
package org.openrewrite.java.marker
-
ClassDescriptionJava 14 introduced compact constructors, which does not include the `()` for parameters.Records a parameter name that appears after a parameter type in a Javadoc method reference, e.g.JavaDoc tags like @return that may be written with a leading brace.Marks a Javadoc DocComment that uses the
///line-style markdown syntax (JEP 467, Java 23+) rather than the traditional/** * /block syntax.Marker indicating null-safe navigation (?.A marker that identifies the project a source file belongs to.Represents escaped identifiers.Represents optional semi-colons on java like languages.Marks aJ.ArrayTypethat was written using varargs syntax (...) rather than array brackets ([]).