Package org.openrewrite.java.search
@NullMarked
@NonNullFields
package org.openrewrite.java.search
-
ClassesClassDescriptionDeclaresType<P>Finds fields that have a matching type.Finds matching method invocations.Lists all symbols (classes, interfaces, enums, records, methods, constructors, fields) declared in the codebase and emits them into a
SymbolsTableDataTable.Acts as a sort of bloom filter for the presence of an import for a particular type in aJ.CompilationUnit, i.e.Recursively checks the equality of each element of two ASTs to determine if two trees are semantically equal.Marks aJavaSourceFileas matching if all the passed methods are found.UsesField<P>UsesMethod<P>UsesType<P>