Package org.openrewrite.java.style
Class WrappingAndBracesStyle
java.lang.Object
org.openrewrite.java.style.WrappingAndBracesStyle
- All Implemented Interfaces:
JavaStyle,org.openrewrite.style.Style
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic classstatic classstatic classstatic classstatic classstatic classstatic classstatic classstatic classstatic classstatic classstatic classstatic classstatic enumstatic classstatic classstatic classstatic classstatic classstatic classstatic classstatic classstatic classstatic classstatic classstatic classstatic classstatic classstatic classstatic classstatic classstatic class -
Constructor Summary
Constructors -
Method Summary
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface org.openrewrite.style.Style
getJacksonPolymorphicTypeTag, merge
-
Constructor Details
-
WrappingAndBracesStyle
public WrappingAndBracesStyle()
-
-
Method Details
-
applyDefaults
public org.openrewrite.style.Style applyDefaults()- Specified by:
applyDefaultsin interfaceorg.openrewrite.style.Style
-