Package org.openrewrite.java.trait
Enum Class AttributeValue.Kind
- All Implemented Interfaces:
Serializable,Comparable<AttributeValue.Kind>,Constable
- Enclosing class:
AttributeValue
The syntactic shape of an annotation attribute value. Exactly one kind applies to
any value; unrecognized or compound shapes classify as
EXPRESSION.-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>> -
Enum Constant Summary
Enum ConstantsEnum ConstantDescription -
Method Summary
Modifier and TypeMethodDescriptionstatic AttributeValue.KindReturns the enum constant of this class with the specified name.static AttributeValue.Kind[]values()Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
LITERAL
-
CLASS_LITERAL
-
ENUM_CONSTANT
-
CONSTANT_REFERENCE
-
NESTED_ANNOTATION
-
ARRAY
-
EXPRESSION
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-