Package org.openrewrite.java.marker
Class Varargs
java.lang.Object
org.openrewrite.java.marker.Varargs
- All Implemented Interfaces:
org.openrewrite.marker.Marker,org.openrewrite.rpc.RpcCodec<Varargs>
public class Varargs
extends Object
implements org.openrewrite.marker.Marker, org.openrewrite.rpc.RpcCodec<Varargs>
Marks a
J.ArrayType that was written using varargs syntax
(...) rather than array brackets ([]). The element type and dimension space are
modeled like any other array type; this marker only records that the type should be printed with
.... Currently produced by the Javadoc parser for references such as
{@link String#format(String, Object...)}.-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionrpcReceive(Varargs before, org.openrewrite.rpc.RpcReceiveQueue q) voidMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface org.openrewrite.marker.Marker
getId, print, withId