Package org.openrewrite.java.marker
@NullMarked
package org.openrewrite.java.marker
-
ClassDescriptionJava 14 introduced compact constructors, which does not include the `()` for parameters.SPI for
JavaSourceSet.classpathbackings that can resolve a fully-qualified name without scanning the entire list.Lazy-aware result ofJavaSourceSet.ClasspathIndex.withGavsRemoved(java.util.Set<java.lang.String>): a paired(classpath, gavToTypes)view onto the surviving partitions.JavaDoc tags like @return that may be written with a leading brace.Marks a Javadoc DocComment that uses the///line-style markdown syntax (JEP 467, Java 23+) rather than the traditional/** * /block syntax.Marker indicating null-safe navigation (?.Represents escaped identifiers.Represents optional semi-colons on java like languages.